==> werkout-server-1.2.6.tgz: package/lib/index.js <==
const jet = require('node-jet')
const { createReservationManager } = require('./reservationManager')
const { withLogging } = require('./decorators/peerWithLogging')
const { loadUsers } = require('./helpers')
const path = require('path')
const fs = require('fs-extra')
const argv = require('yargs')
  .command(
    '',
    'Serves a directory over HTTP and accepts WS connections for node-jet.'
  )
  .example('$0 -d ./dist -p 8090')
  .options({
    p: {
      alias: 'port',
      demandOption: false,
      default: '8090',
      describe: 'TCP port to use for HTTP and WS',
      type: 'number'
    },
    k: {
      alias: 'key',
      demandOption: false,
      describe:
        'The path to the key for SSL. Must provide --cert as well. Using these options will cause the server to only accept secure connections.'
    },
    c: {
      alias: 'cert',
      demandOption: false,
      describe:
        'The path to the certificate for SSL. Must provide --key as well. Using these options will cause the server to only accept secure connections.'
    }
  })
  .check(argv => {
    if (argv.key || argv.cert) {
      if (!argv.key || !argv.cert) {
        throw Error(
          `ERROR: Using the key or cert option requires both to be provided!`
        )
      }
    }
    return true
  })
  .help('h')
  .alias('h', 'help').argv

let httpServer

if (argv.key && argv.cert) {
  const https = require('https')
  const options = {
    key: fs.readFileSync(path.resolve(argv.key)),
    cert: fs.readFileSync(path.resolve(argv.cert))
  }
  // Create Webserver and start listening on given or default port
  httpServer = https.createServer(options)
} else {
  const http = require('http')
  // Create Webserver and start listening on given or default port
  httpServer = http.createServer()
}

httpServer.listen(argv.port)

// Create Jet Daemon
const daemon = new jet.Daemon()

daemon.on('connection', function (peer) {
  console.log(`Peer Connected: ${peer.id}`)
})

daemon.on('disconnect', function (peer) {
  console.log(`Peer Disconnected: ${peer.id}`)
})

const localPeer = daemon.createLocalPeer()

localPeer
  .connect()
  .then(() => createReservationManager(withLogging(localPeer), daemon))
  .then(() => loadUsers(localPeer))
  .then(() => {
    daemon.listen({
      server: httpServer
    })
  })
  .catch(e => console.error(e))

==> werkout-server-1.4.0.tgz: package/lib/index.js <==
const { logger } = require('./logger')
const jet = require('node-jet')
const { createReservationManager } = require('./reservationManager')
const { withLogging } = require('./decorators/peerWithLogging')
const { loadUsers } = require('./helpers')
const path = require('path')
const fs = require('fs-extra')
const resolveCwd = require('resolve-cwd')
const argv = require('yargs')
  .command(
    '',
    'Serves a directory over HTTP and accepts WS connections for node-jet.'
  )
  .example('$0 -d ./dist -p 8090')
  .options({
    p: {
      alias: 'port',
      demandOption: false,
      default: '8090',
      describe: 'TCP port to use for HTTP and WS',
      type: 'number'
    },
    k: {
      alias: 'key',
      demandOption: false,
      describe:
        'The path to the key for SSL. Must provide --cert as well. Using these options will cause the server to only accept secure connections.'
    },
    c: {
      alias: 'cert',
      demandOption: false,
      describe:
        'The path to the certificate for SSL. Must provide --key as well. Using these options will cause the server to only accept secure connections.'
    },
    u: {
      alias: 'users',
      demandOption: false,
      describe: 'The path to a `.json` of user account information.'
    }
  })
  .check(argv => {
    if (argv.key || argv.cert) {
      if (!argv.key || !argv.cert) {
        throw Error(
          `ERROR: Using the key or cert option requires both to be provided!`
        )
      }
    }
    return true
  })
  .help('h')
  .alias('h', 'help').argv

let httpServer

if (argv.key && argv.cert) {
  const https = require('https')
  const options = {
    key: fs.readFileSync(path.resolve(argv.key)),
    cert: fs.readFileSync(path.resolve(argv.cert))
  }
  // Create Webserver and start listening on given or default port
  httpServer = https.createServer(options)
} else {
  const http = require('http')
  // Create Webserver and start listening on given or default port
  httpServer = http.createServer()
}

httpServer.listen(argv.port)

// Create Jet Daemon
const daemon = new jet.Daemon()

daemon.on('connection', function (peer) {
  logger.info(`Peer Connected: ${peer.id}`)
})

daemon.on('disconnect', function (peer) {
  logger.info(`Peer Disconnected: ${peer.id}`)
})

const localPeer = daemon.createLocalPeer()

localPeer
  .connect()
  .then(() => createReservationManager(withLogging(localPeer), daemon))
  .then(() => {
    if (argv.users) {
      return loadUsers(localPeer, resolveCwd(argv.users))
    } else {
      logger.warn('Path to users JSON not found.')
    }
  })
  .then(() => {
    daemon.listen({
      server: httpServer
    })
  })
  .catch(e => logger.error(e))
